@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 import os
 import ant
-
+import uuid
 from rfsdk.protocol.service_method import *
 
 
@@ -15,7 +15,7 @@ class Gateway(object):
         self._server = None
         self._option = ant.Option()
         self._protocol_head = None
-        self._service_name = SERVICE_GATEWAY
+        self._service_name =str(uuid.uuid4())[0:6]
         self._use_verbose_log = True
         self._is_console_log = True
         self._log_dir = os.path.join(os.path.dirname(os.getcwd()) + '/log')
