@@ -573,6 +573,11 @@ def make_query_instrument_req(investor_key,  # 投资者唯一编号
     return generate_req(inspect.currentframe())
 
 
+# 查询投资者结果确认
+def make_confirm_settlement_info_req(investor_key, broker_id, investor_id, trading_day, account_id, currency_id):
+    return generate_req(inspect.currentframe())
+
+
 # 查询投资者结算结果
 def make_query_settlement_info_req(investor_key,  # 投资者key
                                    broker_id,  # 经纪商id
@@ -822,15 +827,15 @@ def make_query_max_order_volume_req(investor_key,  # 投资者唯一编码
 
 
 # 请求查询客户通知
-def make_qry_notice_req(investor_key  # 投资者唯一编码
-                        ):
+def make_query_notice_req(investor_key  # 投资者唯一编码
+                          ):
     return generate_req(inspect.currentframe())
 
 
 # 请求查询交易通知
-def make_qry_trading_notice_req(investor_key,  # 投资者唯一编码
-                                investor_unit_id  # 投资单元代码
-                                ):
+def make_query_trading_notice_req(investor_key,  # 投资者唯一编码
+                                  investor_unit_id  # 投资单元代码
+                                  ):
     return generate_req(inspect.currentframe())
 
 
